==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Input/wavpack/translations/wavpack_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="44"/>
        <source>WavPack Plugin</source>
        <translation>WavPack プラグイン</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="46"/>
        <source>WavPack Files</source>
        <translation>WavPack ファイル</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="132"/>
        <source>About WavPack Audio Plugin</source>
        <translation>WavPack 音響プラグインについて</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="133"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>QMMP WavPack 音響プラグイン</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="134"/>
        <source>WavPack library version:</source>
        <translation>WavPack ライブラリのバージョン:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="136"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="66"/>
        <source>Length</source>
        <translation>長さ</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="67"/>
        <source>Sample rate</source>
        <translation>サンプルレート</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="67"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="68"/>
        <source>Channels</source>
        <translation>チャンネル</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="69"/>
        <source>Bitrate</source>
        <translation>ビットレート</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="69"/>
        <source>kbps</source>
        <translation>キロビット毎秒</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>File size</source>
        <translation>ファイルの大きさ</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>KB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Ratio</source>
        <translation>率</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Version</source>
        <translation>版</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Input/wavpack/translations/wavpack_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="45"/>
        <source>WavPack Plugin</source>
        <translation>WavPack プラグイン</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="47"/>
        <source>WavPack Files</source>
        <translation>WavPack ファイル</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="161"/>
        <source>About WavPack Audio Plugin</source>
        <translation>WavPack 音響プラグインについて</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="162"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>QMMP WavPack 音響プラグイン</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="163"/>
        <source>WavPack library version:</source>
        <translation>WavPack ライブラリのバージョン:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="165"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
        <source>Length</source>
        <translation>長さ</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Sample rate</source>
        <translation>サンプルレート</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Channels</source>
        <translation>チャンネル</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Bitrate</source>
        <translation>ビットレート</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>kbps</source>
        <translation>キロビット毎秒</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="75"/>
        <source>File size</source>
        <translation>ファイルの大きさ</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="75"/>
        <source>KB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="76"/>
        <source>Ratio</source>
        <translation>率</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="77"/>
        <source>Version</source>
        <translation>版</translation>
    </message>
</context>
</TS>
